@@ -3,11 +3,11 @@ use Dancer ':syntax';
 
 use 5.008005;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Data::Dumper qw(Dumper);
 use Dwimmer::DB;
-use Dwimmer::Tools qw(_get_db _get_site read_file $SCHEMA_VERSION);
+use Dwimmer::Tools qw(_get_db _get_site _get_redirect read_file $SCHEMA_VERSION);
 
 use Encode     qw(decode);
 use Fcntl      qw(:flock);
@@ -38,6 +38,12 @@ hook before => sub {
 	if ( $version != $SCHEMA_VERSION ) {
 		return halt("Database is currently at version $version while we need version $SCHEMA_VERSION");
 	}
+	my ( $host, $url ) = _get_redirect();
+	if ($host) {
+		debug("Redirection to $url");
+		return redirect $url;
+	}
+
 	my ( $site_name, $site ) = _get_site();
 	return halt("Could not find site called '$site_name' in the database") if not $site;
 
@@ -57,6 +63,16 @@ hook before => sub {
 	return;
 };
 
+get '/search' => sub {
+	my $text = param('text');
+	return 'No search term provided'
+		if not defined $text or $text =~ /^\s*$/;
+
+	my $results = Dwimmer::Admin::search(text => $text);
+	template 'search_results', { results => $results };
+};
+
+
 sub route_index {
 	my ( $site_name, $site ) = _get_site();
 
@@ -71,9 +87,10 @@ sub route_index {
 			}
 		}
 
-		$data->{body} =~ s{\[(\w+)://([^]]+)\]}{_process($1, $2)}eg;
+		# disable special tag processing for now, will need to
+		$data->{body} =~ s{\[\[(\w+)://([^]]+)\]\]}{_process($1, $2)}eg;
+		$data->{body} =~ s{\[\[([\w .\$@%-]+)\]\]}{<a href="$1">$1</a>}g;
 
-		$data->{body} =~ s{\[([\w .\$@%-]+)\]}{<a href="$1">$1</a>}g;
 		return Dwimmer::Admin::render_response( 'index', { page => $data } );
 	} else {
 
