@@ -3,7 +3,7 @@ use Dancer ':syntax';
 
 use 5.008005;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Data::Dumper qw(Dumper);
 use Email::Valid   ();
@@ -718,24 +718,30 @@ sub _set_site_config {
 }
 
 get '/search.json' => sub {
-	my ($site_name, $site) = _get_site();
-
 	my %params = _clean_params(qw(text));
 	return to_json { error => 'no_search_text' } if not $params{text};
 
+	my $data = search(%params);
+	to_json {ok => 1, data => $data};
+};
+
+sub search {
+	my %params = @_;
+
+	my ($site_name, $site) = _get_site();
 	my $db = _get_db();
 
-	# in each page (last
-	my @history = map { {
-		revision  => $_->revision,
-		timestamp => $_->timestamp,
-		author    => $_->author->name,
-#		filename  => $path,
-	} }
-	$db->resultset('PageHistory')->search( { siteid => $site->id, filename => $params{text} } );
+	debug("sarch for '$params{text}'");
 #	title, body, description, abstract, filename
-
-};
+	my @results = map { {
+			title => $_->filename,
+			filename => $_->filename,
+		} }  $db->resultset('Page')->search( {
+			siteid => $site->id,
+			filename => { like => ('%' . $params{text} . '%') },
+			} );
+	return \@results;
+}
 
 
 true;
